@@ -95,6 +95,10 @@ class BasicTest(unittest.TestCase, BasicHelper):
         num = 50
         self.assertEqual(num, len(list(self.r.get_new(limit=num))))
 
+    def test_get_popular_reddits(self):
+        num = 50
+        self.assertEqual(num, len(list(self.r.get_popular_reddits(limit=num))))
+
     def test_flair_list(self):
         sub = self.r.get_subreddit('python')
         self.assertTrue(six_next(sub.flair_list()))
